@@ -1,5 +1,6 @@
 import os
 
+import django
 from django.conf import global_settings
 
 
@@ -57,7 +58,6 @@ INSTALLED_APPS = [
     'django.contrib.admin',
 
     'taggit',
-    'south',
     'compressor',
 
     'wagtail.wagtailcore',
@@ -68,7 +68,6 @@ INSTALLED_APPS = [
     'wagtail.wagtailimages',
     'wagtail.wagtailembeds',
     'wagtail.wagtailsearch',
-    'wagtail.wagtailredirects',
     'wagtail.wagtailforms',
     'wagtail.contrib.wagtailstyleguide',
     'wagtail.contrib.wagtailsitemaps',
@@ -76,6 +75,27 @@ INSTALLED_APPS = [
     'wagtail.tests',
 ]
 
+# If we are using Django 1.6, add South to INSTALLED_APPS
+if django.VERSION < (1, 7):
+    INSTALLED_APPS.append('south')
+
+
+# If we are using Django 1.7 install wagtailredirects with its appconfig
+# Theres nothing special about wagtailredirects, we just need to have one
+# app which uses AppConfigs to test that hooks load properly
+
+if django.VERSION < (1, 7):
+    INSTALLED_APPS.append('wagtail.wagtailredirects')
+else:
+    INSTALLED_APPS.append('wagtail.wagtailredirects.apps.WagtailRedirectsAppConfig')
+
+# As we don't have south migrations for tests, South thinks
+# the Django 1.7 migrations are South migrations.
+SOUTH_MIGRATION_MODULES = {
+    'tests': 'ignore',
+}
+
+
 # Using DatabaseCache to make sure that the cache is cleared between tests.
 # This prevents false-positives in some wagtail core tests where we are
 # changing the 'wagtail_root_paths' key which may cause future tests to fail.
