@@ -5,7 +5,7 @@ from six import string_types
 from six import StringIO
 from six.moves.urllib.parse import urlparse
 
-from modelcluster.models import ClusterableModel
+from modelcluster.models import ClusterableModel, get_all_child_relations
 
 from django.db import models, connection, transaction
 from django.db.models import get_model, Q
@@ -13,6 +13,7 @@ from django.http import Http404
 from django.core.cache import cache
 from django.core.handlers.wsgi import WSGIRequest
 from django.core.handlers.base import BaseHandler
+from django.core.urlresolvers import reverse
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.auth.models import Group
 from django.conf import settings
@@ -25,13 +26,11 @@ from django.utils.encoding import python_2_unicode_compatible
 
 from treebeard.mp_tree import MP_Node
 
-from wagtail.utils.deprecation import RemovedInWagtail06Warning
-
 from wagtail.wagtailcore.utils import camelcase_to_underscore
 from wagtail.wagtailcore.query import PageQuerySet
 from wagtail.wagtailcore.url_routing import RouteResult
 
-from wagtail.wagtailsearch import indexed
+from wagtail.wagtailsearch import index
 from wagtail.wagtailsearch.backends import get_search_backend
 
 
@@ -148,31 +147,6 @@ def get_page_types():
     return _PAGE_CONTENT_TYPES
 
 
-def get_leaf_page_content_type_ids():
-    warnings.warn("""
-        get_leaf_page_content_type_ids is deprecated, as it treats pages without an explicit subpage_types
-        setting as 'leaf' pages. Code that calls get_leaf_page_content_type_ids must be rewritten to avoid
-        this incorrect assumption.
-    """, RemovedInWagtail06Warning)
-    return [
-        content_type.id
-        for content_type in get_page_types()
-        if not getattr(content_type.model_class(), 'subpage_types', None)
-    ]
-
-def get_navigable_page_content_type_ids():
-    warnings.warn("""
-        get_navigable_page_content_type_ids is deprecated, as it treats pages without an explicit subpage_types
-        setting as 'leaf' pages. Code that calls get_navigable_page_content_type_ids must be rewritten to avoid
-        this incorrect assumption.
-    """, RemovedInWagtail06Warning)
-    return [
-        content_type.id
-        for content_type in get_page_types()
-        if getattr(content_type.model_class(), 'subpage_types', None)
-    ]
-
-
 class PageManager(models.Manager):
     def get_queryset(self):
         return PageQuerySet(self.model).order_by('path')
@@ -273,7 +247,7 @@ class PageBase(models.base.ModelBase):
 
 
 @python_2_unicode_compatible
-class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Indexed)):
+class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, index.Indexed)):
     title = models.CharField(max_length=255, help_text=_("The page title as you'd like it to be seen by the public"))
     slug = models.SlugField(help_text=_("The name of the page as it will appear in URLs e.g http://domain.com/blog/[my-slug]/"))
     # TODO: enforce uniqueness on slug field per parent (will have to be done at the Django
@@ -293,13 +267,13 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
     expired = models.BooleanField(default=False, editable=False)
 
     search_fields = (
-        indexed.SearchField('title', partial_match=True, boost=100),
-        indexed.FilterField('id'),
-        indexed.FilterField('live'),
-        indexed.FilterField('owner'),
-        indexed.FilterField('content_type'),
-        indexed.FilterField('path'),
-        indexed.FilterField('depth'),
+        index.SearchField('title', partial_match=True, boost=100),
+        index.FilterField('id'),
+        index.FilterField('live'),
+        index.FilterField('owner'),
+        index.FilterField('content_type'),
+        index.FilterField('path'),
+        index.FilterField('depth'),
     )
 
     def __init__(self, *args, **kwargs):
@@ -475,20 +449,12 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
         """
         return (not self.is_leaf()) or self.depth == 2
 
-    def get_other_siblings(self):
-        warnings.warn(
-            "The 'Page.get_other_siblings()' method has been replaced. "
-            "Use 'Page.get_siblings(inclusive=False)' instead.", RemovedInWagtail06Warning)
-
-        # get sibling pages excluding self
-        return self.get_siblings().exclude(id=self.id)
-
     @property
     def full_url(self):
         """Return the full URL (including protocol / domain) to this page, or None if it is not routable"""
         for (id, root_path, root_url) in Site.get_site_root_paths():
             if self.url_path.startswith(root_path):
-                return root_url + self.url_path[len(root_path) - 1:]
+                return root_url + reverse('wagtail_serve', args=(self.url_path[len(root_path):],))
 
     @property
     def url(self):
@@ -503,7 +469,7 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
         root_paths = Site.get_site_root_paths()
         for (id, root_path, root_url) in Site.get_site_root_paths():
             if self.url_path.startswith(root_path):
-                return ('' if len(root_paths) == 1 else root_url) + self.url_path[len(root_path) - 1:]
+                return ('' if len(root_paths) == 1 else root_url) + reverse('wagtail_serve', args=(self.url_path[len(root_path):],))
 
     def relative_url(self, current_site):
         """
@@ -513,7 +479,7 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
         """
         for (id, root_path, root_url) in Site.get_site_root_paths():
             if self.url_path.startswith(root_path):
-                return ('' if current_site.id == id else root_url) + self.url_path[len(root_path) - 1:]
+                return ('' if current_site.id == id else root_url) + reverse('wagtail_serve', args=(self.url_path[len(root_path):],))
 
     @classmethod
     def search(cls, query_string, show_unpublished=False, search_title_only=False, extra_filters={}, prefetch_related=[], path=None):
@@ -587,6 +553,9 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
 
     @classmethod
     def get_verbose_name(cls):
+        """
+            Returns the human-readable "verbose name" of this page model e.g "Blog page".
+        """
         # This is similar to doing cls._meta.verbose_name.title()
         # except this doesn't convert any characters to lowercase
         return ' '.join([word[0].upper() + word[1:] for word in cls._meta.verbose_name.split()])
@@ -652,7 +621,7 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
 
         # Copy child objects
         specific_self = self.specific
-        for child_relation in getattr(specific_self._meta, 'child_relations', []):
+        for child_relation in get_all_child_relations(specific_self):
             parental_key_name = child_relation.field.attname
             child_objects = getattr(specific_self, child_relation.get_accessor_name(), None)
 
@@ -727,15 +696,6 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
         for example, a page containing a form might have a default view of the form,
         and a post-submission 'thankyou' page
         """
-        modes = self.get_page_modes()
-        if modes is not Page.DEFAULT_PREVIEW_MODES:
-            # User has overriden get_page_modes instead of using preview_modes
-            warnings.warn("Overriding get_page_modes is deprecated. Define a preview_modes property instead", RemovedInWagtail06Warning)
-
-        return modes
-
-    def get_page_modes(self):
-        # Deprecated accessor for the preview_modes property
         return Page.DEFAULT_PREVIEW_MODES
 
     @property
@@ -769,12 +729,6 @@ class Page(six.with_metaclass(PageBase, MP_Node, ClusterableModel, indexed.Index
         """
         return self.serve(request)
 
-    def show_as_mode(self, mode_name):
-        # Deprecated API for rendering previews. If this returns something other than None,
-        # we know that a subclass of Page has overridden this, and we should try to work with
-        # that response if possible.
-        return None
-
     def get_cached_paths(self):
         """
         This returns a list of paths to invalidate in a frontend cache
