@@ -17,12 +17,13 @@ def register_admin_urls():
     ]
 
 
-@hooks.register('construct_main_menu')
-def construct_main_menu(request, menu_items):
-    if request.user.has_perm('wagtaildocs.add_document'):
-        menu_items.append(
-            MenuItem(_('Documents'), urlresolvers.reverse('wagtaildocs_index'), classnames='icon icon-doc-full-inverse', order=400)
-        )
+class DocumentsMenuItem(MenuItem):
+    def is_shown(self, request):
+        return request.user.has_perm('wagtaildocs.add_document')
+
+@hooks.register('register_admin_menu_item')
+def register_documents_menu_item():
+    return DocumentsMenuItem(_('Documents'), urlresolvers.reverse('wagtaildocs_index'), classnames='icon icon-doc-full-inverse', order=400)
 
 
 @hooks.register('insert_editor_js')
