@@ -22,30 +22,30 @@ from unidecode import unidecode
 
 from wagtail.wagtailadmin.taggable import TagSearchable
 from wagtail.wagtailimages.backends import get_image_backend
-from wagtail.wagtailsearch import indexed
+from wagtail.wagtailsearch import index
 from wagtail.wagtailimages.utils.validators import validate_image_format
 from wagtail.wagtailimages.utils.focal_point import FocalPoint
 from wagtail.wagtailimages.utils.feature_detection import FeatureDetector, opencv_available
 from wagtail.wagtailadmin.utils import get_object_usage
 
 
+def get_upload_to(instance, filename):
+    folder_name = 'original_images'
+    filename = instance.file.field.storage.get_valid_name(filename)
+
+    # do a unidecode in the filename and then
+    # replace non-ascii characters in filename with _ , to sidestep issues with filesystem encoding
+    filename = "".join((i if ord(i) < 128 else '_') for i in unidecode(filename))
+
+    while len(os.path.join(folder_name, filename)) >= 95:
+        prefix, dot, extension = filename.rpartition('.')
+        filename = prefix[:-1] + dot + extension
+    return os.path.join(folder_name, filename)
+
+
 @python_2_unicode_compatible
 class AbstractImage(models.Model, TagSearchable):
     title = models.CharField(max_length=255, verbose_name=_('Title') )
-
-    def get_upload_to(self, filename):
-        folder_name = 'original_images'
-        filename = self.file.field.storage.get_valid_name(filename)
-
-        # do a unidecode in the filename and then
-        # replace non-ascii characters in filename with _ , to sidestep issues with filesystem encoding
-        filename = "".join((i if ord(i) < 128 else '_') for i in unidecode(filename))
-
-        while len(os.path.join(folder_name, filename)) >= 95:
-            prefix, dot, extension = filename.rpartition('.')
-            filename = prefix[:-1] + dot + extension
-        return os.path.join(folder_name, filename)
-
     file = models.ImageField(verbose_name=_('File'), upload_to=get_upload_to, width_field='width', height_field='height', validators=[validate_image_format])
     width = models.IntegerField(editable=False)
     height = models.IntegerField(editable=False)
@@ -68,7 +68,7 @@ class AbstractImage(models.Model, TagSearchable):
                        args=(self.id,))
 
     search_fields = TagSearchable.search_fields + (
-        indexed.FilterField('uploaded_by_user'),
+        index.FilterField('uploaded_by_user'),
     )
 
     def __str__(self):
@@ -161,10 +161,9 @@ class AbstractImage(models.Model, TagSearchable):
 
             input_filename_parts = os.path.basename(file_field.file.name).split('.')
             filename_without_extension = '.'.join(input_filename_parts[:-1])
-            filename_without_extension = filename_without_extension[:60]  # trim filename base so that we're well under 100 chars
-            output_filename_parts = [filename_without_extension, focal_point_key, filter.spec] + input_filename_parts[-1:]
-            output_filename = '.'.join(output_filename_parts)
-
+            extension = '.'.join([focal_point_key, filter.spec] + input_filename_parts[-1:])
+            filename_without_extension = filename_without_extension[:(59-len(extension))] # Truncate filename to prevent it going over 60 chars
+            output_filename = filename_without_extension + '.' + extension
             generated_image_file = File(generated_image, name=output_filename)
 
             if self.focal_point:
