@@ -1,7 +1,8 @@
 from django import forms
 from django.forms.models import inlineformset_factory
 from django.utils.translation import ugettext_lazy as _
-import models
+
+from wagtail.wagtailsearch import models
 
 
 class QueryForm(forms.Form):
@@ -31,6 +32,8 @@ EditorsPickFormSetBase = inlineformset_factory(models.Query, models.EditorsPick,
 
 
 class EditorsPickFormSet(EditorsPickFormSetBase):
+    minimum_forms = 1
+    minimum_forms_message = _("Please specify at least one recommendation for this search term.")
     def add_fields(self, form, *args, **kwargs):
         super(EditorsPickFormSet, self).add_fields(form, *args, **kwargs)
 
@@ -40,3 +43,20 @@ class EditorsPickFormSet(EditorsPickFormSetBase):
 
         # Remove query field
         del form.fields['query']
+
+    def clean(self):
+        # Editors pick must have at least one recommended page to be valid
+        # Check there is at least one non-deleted form.
+        non_deleted_forms = self.total_form_count()
+        non_empty_forms = 0
+        for i in range(0, self.total_form_count()):
+            form = self.forms[i]
+            if self.can_delete and self._should_delete_form(form):
+                non_deleted_forms -= 1
+            if not (form.instance.id is None and not form.has_changed()):
+                non_empty_forms += 1
+        if (
+            non_deleted_forms < self.minimum_forms
+            or non_empty_forms < self.minimum_forms
+        ):
+            raise forms.ValidationError(self.minimum_forms_message)
