@@ -15,9 +15,10 @@ def register_admin_urls():
     ]
 
 
-@hooks.register('construct_main_menu')
-def construct_main_menu(request, menu_items):
-    if request.user.has_module_perms('auth'):
-        menu_items.append(
-            MenuItem(_('Users'), urlresolvers.reverse('wagtailusers_index'), classnames='icon icon-user', order=600)
-        )
+class UsersMenuItem(MenuItem):
+    def is_shown(self, request):
+        return request.user.has_module_perms('auth')
+
+@hooks.register('register_admin_menu_item')
+def register_users_menu_item():
+    return UsersMenuItem(_('Users'), urlresolvers.reverse('wagtailusers_index'), classnames='icon icon-user', order=600)
